@@ -98,7 +98,7 @@ class TakemeClient:
         self.auth_call(body, endpoint, jwt)
 
     def user_change_pin(self, old_pin, new_pin, jwt):
-        endpoint = "user/save-pin"
+        endpoint = "user/change-pin"
         body = {
             "old_pin": RsaUtil.encrypt(old_pin),
             "new_pin": RsaUtil.encrypt(new_pin)
@@ -167,3 +167,11 @@ class TakemeClient:
         response = self.auth_call_with_pin(body, endpoint, jwt, pin)
 
         return response.get("data")
+
+    def aggregate_balance(self):
+        endpoint = "corporate/aggregate-balance"
+        body = None
+
+        response = self.non_auth_call(body, endpoint)
+
+        return response.get("data")
\ No newline at end of file
